@@ -4,9 +4,9 @@ import os
 import sys
 
 import google.api_core.exceptions
+from google import auth
 from google.cloud import secretmanager
 
-from octue.cloud.credentials import GCPCredentialsManager
 from octue.log_handlers import apply_log_handler, create_octue_formatter, get_log_record_attributes_for_environment
 from octue.resources import Child
 from octue.resources.analysis import CLASS_MAP, Analysis
@@ -202,13 +202,11 @@ class Runner:
         if not missing_credentials:
             return
 
-        google_cloud_credentials = GCPCredentialsManager().get_credentials()
+        google_cloud_credentials, project_name = auth.default()
         secrets_client = secretmanager.SecretManagerServiceClient(credentials=google_cloud_credentials)
 
         if google_cloud_credentials is None:
             project_name = self._project_name
-        else:
-            project_name = google_cloud_credentials.project_id
 
         for credential in missing_credentials:
             secret_path = secrets_client.secret_version_path(
