@@ -229,8 +229,8 @@ class MockService(Service):
     :return None:
     """
 
-    def __init__(self, backend, service_id=None, run_function=None, children=None):
-        super().__init__(backend, service_id, run_function)
+    def __init__(self, backend, service_id=None, run_function=None, children=None, *args, **kwargs):
+        super().__init__(backend, service_id, run_function, *args, **kwargs)
         self.children = children or {}
         self.publisher = MockPublisher()
         self.subscriber = MockSubscriber()
@@ -242,8 +242,8 @@ class MockService(Service):
         input_manifest=None,
         subscribe_to_logs=True,
         allow_local_files=False,
-        timeout=30,
         question_uuid=None,
+        timeout=30,
     ):
         """Put the question into the messages register, register the existence of the corresponding response topic, add
         the response to the register, and return a MockFuture containing the answer subscription path.
@@ -257,7 +257,13 @@ class MockService(Service):
         :return MockFuture, str:
         """
         response_subscription, question_uuid = super().ask(
-            service_id, input_values, input_manifest, subscribe_to_logs, allow_local_files, timeout, question_uuid
+            service_id,
+            input_values,
+            input_manifest,
+            subscribe_to_logs,
+            allow_local_files,
+            question_uuid,
+            timeout,
         )
 
         # Ignore any errors from the answering service as they will be raised on the remote service in practice, not
